from setuptools import setup, find_namespace_packages

setup(name='PhysioKit2',
      version='1.7.0',
      description="PhysioKit is a novel physiological computing toolkit which is open-source, accessible and affordable. HCI hobbyists and practitioners can easily access physiological sensing channels that help monitor our physiological signatures and vital signs including heart rate, heart rate variability, breathing rate, electrodermal activities. The toolkit works with a low-cost micro-controller such as Arduino. Currently, it supports acquiring EDA, Resp and PPG using any low-cost Arduino board.",
      url='https://github.com/PhysiologicAILab/PhysioKit',
      author=['Jitesh Joshi', 'Katherine wang', 'Youngjun Cho'],
      author_email='youngjun.cho@ucl.ac.uk',
      license='MIT',
      install_requires=[
        'matplotlib',
        'neurokit2',
        'numpy',
        'opencv_contrib_python',
        'pyserial',
        'PySide6',
        'PySide6_Addons',
        'PySide6_Essentials',
        'scipy',
        'pandas',
        'torch',
        'setuptools'
      ],
      packages=find_namespace_packages(where="src"),
      package_dir={"": "src"},
      include_package_data=True,
      package_data={
          "PhysioKit2": ["*.txt"],
          "PhysioKit2": ["*.ui"],
          "PhysioKit2.images": ["*.png"],
          "PhysioKit2.sqa.ckpt": ["*.pth"],
          "PhysioKit2.sqa.config": ["*.json"],
          "PhysioKit2.analysis_helper.sample_data": ["*.txt"],
          "PhysioKit2.configs": ["*.json"],
          "PhysioKit2.configs.arm_due": ["*.json"],
          "PhysioKit2.configs.avr_default": ["*.json"],
      },
      exclude_package_data={"PhysioKit2": [".gitattributes"]}
      )